from django.shortcuts import render, get_object_or_404, redirect
from webapp.forms import ArticleForm
from webapp.models import Article


# CRUD - Create Read Update Delete


def index_view(request):
    context = {'articles': Article.objects.all()}

    return render(request, 'index.html', context)


def article_detail_view(request, id):
    context = {'article': get_object_or_404(Article, id=id)}
 
    return render(request, 'articles/detail.html', context)


def article_create_view(request):
    if request.method == 'GET':
        form = ArticleForm()
        return render(request, 'articles/create.html', context={'form': form})

    elif request.method == 'POST':
        print(request.POST)
        form = ArticleForm(data=request.POST)

        if form.is_valid():
            article = Article.objects.create(
                title=request.POST.get('title'),
                text=request.POST.get('text'),
                author=request.POST.get('author'),
            )
            return redirect('articles_detail', id=article.id)
    
        else:            
           return render(
               request, 'articles/create.html', 
               context={'form': form},
            ) 


def article_update_view(request, id):
    article = get_object_or_404(Article, id=id)
    
    if request.method == 'GET':
        form = ArticleForm(initial={
            'title': article.title,
            'text': article.text,
            'author': article.author,
        })

        return render(
            request, 'articles/update.html', 
            context={'article': article, 'form': form},
        )
    
    elif request.method == 'POST':
        form = ArticleForm(data=request.POST)
        
        if form.is_valid():
            article.title = form.cleaned_data.get('title')
            article.author = form.cleaned_data.get('author')
            article.text = form.cleaned_data.get('text')
            
            article.save()

            return redirect('index')
        else:
            return render(request, 'articles/update.html', context={'form': form, 'article': article})


def article_delete_view(request, id):
    get_object_or_404(Article, id=id).delete()
    
    return redirect('index')
